@@ -6,11 +6,11 @@ and djangoware.
 Copyright (C) 2016 by SolarWinds, LLC.
 All rights reserved.
 """
-from appoptics_apm import util
+from appoptics_apm import config
 
 
 def _enabled(m):
-    return util.config['inst_enabled'][m]
+    return config['inst_enabled'][m]
 
 
 def load_inst_modules():
