@@ -605,9 +605,7 @@ public:
              int max_transactions,           // maximum number of transaction names to track
              int max_flush_wait_time,        // maximum wait time for flushing data before terminating in milli seconds
              int events_flush_interval,      // events flush timeout in seconds (threshold for batching messages before sending off)
-             int events_flush_batch_size,    // events flush batch size in KB (threshold for batching messages before sending off)
-
-
+             int max_request_size_bytes,     // limit max RPC request size
              std::string reporter,           // the reporter to be used ("ssl", "upd", "file", "null")
              std::string host,               // collector endpoint (reporter=ssl), udp address (reporter=udp), or file path (reporter=file)
              std::string service_key,        // the service key (also known as access_key)
@@ -620,13 +618,17 @@ public:
              int token_bucket_rate,          // custom token bucket rate
              int file_single,                // use single files in file reporter for each event
 
-             int ec2_metadata_timeout        // the timeout (milli seconds) for retrieving EC2 metadata
+             int ec2_metadata_timeout,       // the timeout (milli seconds) for retrieving EC2 metadata
+             std::string proxy               // HTTP proxy address and port to be used for the gRPC connection
              ) {
 
         oboe_init_options_t options;
         memset(&options, 0, sizeof(options));
-        options.version = 7;
-        oboe_init_options_set_defaults(&options);
+        options.version = 9;
+        int result = oboe_init_options_set_defaults(&options);
+        if (result != OBOE_INIT_OPTIONS_SET_DEFAULTS_OK) {
+            std::cerr << "Could not set defaults. Error code is " << result << std::endl;
+        }
 
         if (hostname_alias != "") {
             options.hostname_alias = hostname_alias.c_str();
@@ -636,7 +638,7 @@ public:
         options.max_transactions = max_transactions;
         options.max_flush_wait_time = max_flush_wait_time;
         options.events_flush_interval = events_flush_interval;
-        options.events_flush_batch_size = events_flush_batch_size;
+        options.max_request_size_bytes = max_request_size_bytes;
         if (reporter != "") {
             options.reporter = reporter.c_str();
         }
@@ -656,6 +658,9 @@ public:
         options.token_bucket_rate = token_bucket_rate;
         options.file_single = file_single;
         options.ec2_metadata_timeout = ec2_metadata_timeout;
+        if (proxy != "") {
+            options.proxy = proxy.c_str();
+        }
 
         init_status = oboe_init(&options);
     }
