@@ -19,6 +19,8 @@ from functools import reduce
 import six
 from decorator import decorator
 
+import appoptics_apm
+import appoptics_apm.transaction_filter as transaction_filter
 from appoptics_apm.version import __version__
 
 # "invalid name ... For type constant"
@@ -28,13 +30,21 @@ from appoptics_apm.version import __version__
 # Agent process start time, which is supposed to be a constant. -- don't modify it.
 AGENT_START_TIME = time.time() * 1e6
 
-# Constants from liboboe
-OBOE_TRACE_NEVER = 0
-OBOE_TRACE_ALWAYS = 1
-OBOE_TRACE_THROUGH = 2
 
-# oboe modules
-OBOE_MODULE_ALL = -1
+class OboeTracingMode(object):
+    """Provides an interface to translate the string representation of tracing_mode to the C-extension equivalent."""
+    OBOE_SETTINGS_UNSET = -1
+    OBOE_TRACE_DISABLED = 0
+    OBOE_TRACE_ENABLED = 1
+
+    @classmethod
+    def get_oboe_trace_mode(cls, tracing_mode):
+        if tracing_mode == 'enabled':
+            return cls.OBOE_TRACE_ENABLED
+        if tracing_mode == 'disabled':
+            return cls.OBOE_TRACE_DISABLED
+        return cls.OBOE_SETTINGS_UNSET
+
 
 # maps Debug level from liboboe: oboe_debug.h
 OBOE_DEBUG_DISABLE = -1
@@ -179,7 +189,6 @@ if TEST_MODE:
         Event as SwigEvent,
         Reporter,
         Metadata,
-        # TODO_Pylint should debugLog stay?
         Span as SwigSpan,
         CustomMetrics,
         MetricTags,
@@ -339,7 +348,8 @@ class AppOpticsApmConfig(object):
         self._config = dict()
         # Update the config with default values
         self._config = {
-            #'sample_rate' and 'tracing_mode' do not have any default values
+            #'sample_rate' and 'tracing_mode' do not have any default values (i.e. they are unset by default)
+            'tracing_mode': None,
             'collector': '',  # the collector address in host:port format.
             'reporter': '',  # the reporter mode, either 'udp' or 'ssl'.
             'debug_level': _OboeDebugLevel.default_level(),
@@ -419,6 +429,11 @@ class AppOpticsApmConfig(object):
         sub_dict = reduce(lambda d, key: d.get(key, None) if isinstance(d, dict) else None, keys[:-1], self._config)
         key = keys[-1]
         try:
+            if key in self.deprecated:
+                # there are no concatenated keys in deprecated, thus we only need to check key here
+                if self._config['warn_deprecated']:
+                    logger.warning('Ignore deprecated key: {}, use {} instead.'.format(key, self.deprecated.get(key)))
+                return
             if keys == ['sample_rate']:
                 sample_rate = float(val)
                 if not 0 <= sample_rate <= 1:
@@ -434,9 +449,19 @@ class AppOpticsApmConfig(object):
                     raise ValueError
                 self._config[key] = val
             elif keys == ['tracing_mode']:
-                if not isinstance(val, six.string_types) or val.lower() not in ['always', 'never']:
+                if not isinstance(val, six.string_types):
                     raise ValueError
-                self._config[key] = val.lower()
+                val = val.lower()
+                if val in ['always', 'never']:
+                    val = 'enabled' if val == 'always' else 'disabled'
+                    if self._config['warn_deprecated']:
+                        logger.warning(
+                            'appoptics_apm.config "tracing_mode" configurations "always" and "never" are deprecated.'
+                            'Please use "enabled" and "disabled" instead.')
+                if val not in ['enabled', 'disabled']:
+                    raise ValueError
+                self._config[key] = val
+                SwigContext.setTracingMode(OboeTracingMode.get_oboe_trace_mode(val))
             elif keys == ['reporter']:
                 if not isinstance(val, six.string_types) or val.lower() not in ['udp', 'ssl', 'null', 'file']:
                     raise ValueError
@@ -482,25 +507,33 @@ class AppOpticsApmConfig(object):
             logger.warning('Failed to read or parse config file: {e}'.format(e=e))
 
         for section in cnf.sections():
-            if section not in ('main', 'transaction', 'inst'):
-                logger.warning('Invalid section: {s} found in {f}'.format(s=section, f=cnf_path))
+            if section in ('main', 'transaction', 'inst'):
+                for key, val in cnf.items(section):
+                    self._set_config_value(section + '.' + key if section != 'main' else key, val)
                 continue
-            for key, val in cnf.items(section):
-                if key in self.deprecated:
-                    # there are no concatenated keys in deprecated, thus check for delimiter in key not necessary
-                    logger.warning('Ignore deprecated key: {}, use {} instead.'.format(key, self.deprecated.get(key)))
-                    continue
-                self._set_config_value(section + '.' + key if section != 'main' else key, val)
+            # check for custom transaction filter configuration settings
+            subsections = section.split(':')
+            if len(subsections) == 3 and subsections[0] == 'transaction' and subsections[1] == 'filter':
+                # convert custom transaction filter rule into configuration dictionary
+                if six.PY2:
+                    config_dict = dict(cnf.items(section))
+                else:
+                    config_dict = cnf[section]
+                if not transaction_filter.add_transaction_filter_rule(config_dict):
+                    logger.warning("Ignoring custom transaction setting [{}]".format(section))
+
+            else:
+                logger.warning('Invalid section: {s} found in {f}'.format(s=section, f=cnf_path))
+
+        if transaction_filter.url_filter:
+            logger.debug("Configured custom transaction filter {}".format(transaction_filter.url_filter))
 
     def __setitem__(self, key, value):
         """Refresh the configurations in liboboe global struct while user changes settings.
         """
         if key == 'tracing_mode':
             self._set_config_value(key, value)
-            if self.get(key) == 'never':
-                SwigContext.setTracingMode(0)
-            elif self.get(key) == 'always':
-                SwigContext.setTracingMode(1)
+            SwigContext.setTracingMode(OboeTracingMode.get_oboe_trace_mode(self.get(key)))
 
         elif key == 'sample_rate':
             self._set_config_value(key, value)
@@ -531,13 +564,10 @@ class AppOpticsApmConfig(object):
         return value if value is not None else default
 
 
-config = AppOpticsApmConfig()
-
-
 def sys_is_traceable():
     """Check if the required system environment variables APPOPTICS_SERVICE_KEY
     is set."""
-    return bool(config.get('service_key'))
+    return bool(appoptics_apm.config.get('service_key'))
 
 
 def appoptics_apm_init():
@@ -550,7 +580,7 @@ def appoptics_apm_init():
     if sys_is_traceable():
         # APPOPTICS_COLLECTOR is fetched by underlying library
         # Unfortunately, this function does not return anything for now.
-        oboe_log_level = _OboeDebugLevel(config['debug_level'])
+        oboe_log_level = _OboeDebugLevel(appoptics_apm.config['debug_level'])
         logger.setLevel(oboe_log_level.python_logging_level())
         if oboe_log_level.is_disable():
             disable_logger()
@@ -580,7 +610,7 @@ def _str_backtrace(backtrace=None):
 
 def _collect_backtraces(module_name):
     """ Return the collect backtraces config value for module """
-    return config['inst'][module_name]['collect_backtraces']
+    return appoptics_apm.config['inst'][module_name]['collect_backtraces']
 
 
 class Context(object):
@@ -641,12 +671,12 @@ class Context(object):
 
     # For starting/stopping traces
     @classmethod
-    def start_trace(cls, layer, xtr=None, force=False):
+    def start_trace(cls, layer, xtr=None, force=False, url_getter=None):
         """Returns a Context and a start event.
         Takes sampling into account -- may return an (invalid Context, event) pair.
         """
         Context.transaction_dict = threading.local()
-        if sample_request(xtr) or force:
+        if sample_request(xtr, url_getter) or force:
             if cls.xtr_is_v2(xtr):
                 xtr = '{ver_task_op}{flag}'.format(ver_task_op=xtr[:-2], flag='01')
                 md = Metadata.fromString(xtr)
@@ -671,7 +701,7 @@ class Context(object):
             else:
                 logger.debug("No sample_source attribute found")
             if sample_rate:
-                event.add_info('SampleRate', int(sample_rate * 1e6))
+                event.add_info('SampleRate', int(sample_rate))
             else:
                 logger.debug("No sample_rate attribute found")
             event.add_info('Language', 'Python')  # in case we have an unclear layer name
@@ -692,7 +722,7 @@ class Context(object):
         """
 
         if not trans_name:
-            logger.warning('Invalid transaction name:{n}'.format(n=_apm_str(trans_name)))
+            logger.debug('Invalid transaction name:{n}'.format(n=_apm_str(trans_name)))
             return False
 
         trans_name = _apm_str(trans_name)
@@ -717,59 +747,62 @@ class Context(object):
            self -- this context instance
            event -- last trace event
         """
-        end_time = time.time() * 1e6
-        domain = getattr(Context.transaction_dict, 'domain', None)
-        if not config['transaction']['prepend_domain_name']:
-            domain = None
-        if domain is not None and len(domain.split(":")) > 1:
-            port = domain.split(":")[1]
-            if port in ('80', '443'):
-                domain = domain.split(":")[0]
-        trans_name = getattr(Context.transaction_dict, 'transaction_name', None)
         http_span = getattr(Context.transaction_dict, 'http', None)
-        request_method = getattr(Context.transaction_dict, 'request_method', None)
-        status_code = getattr(Context.transaction_dict, 'status_code', None)
+        do_metrics = getattr(Context.transaction_dict, 'do_metrics', None)
+        trans_name = getattr(Context.transaction_dict, 'transaction_name', None)
+        # non-http requests are not subject to transaction filtering and should always report metrics
+        if not http_span or do_metrics:
+            end_time = time.time() * 1e6
+            domain = getattr(Context.transaction_dict, 'domain', None)
+            if not appoptics_apm.config['transaction']['prepend_domain_name']:
+                domain = None
+            if domain is not None and len(domain.split(":")) > 1:
+                port = domain.split(":")[1]
+                if port in ('80', '443'):
+                    domain = domain.split(":")[0]
 
-        start_time = getattr(Context.transaction_dict, 'start_time', None)
-        if start_time is None:
-            start_time = end_time
-            logger.warning('trace start_time not recorded')
-        else:
-            start_time = int(start_time)
-        url_tran = None if trans_name else getattr(Context.transaction_dict, 'url_tran', None)
-        span_time = int(end_time - start_time)
-
-        try:
-            if http_span:
-                if request_method is None or status_code is None:
-                    logger.warning(
-                        'http_span request info error request_method: {r}, status_code: {s}'.format(
-                            r=request_method, s=status_code))
-                if trans_name is None and url_tran is None:
-                    logger.warning(
-                        'http_span error: transaction_name is None, \
-                                use set_transaction_name("transaction_name") to set')
-                if status_code is None:
-                    status_code = 0
-                has_error = bool(status_code > 499) and bool(status_code < 600)
-                trans_name = SwigSpan.createHttpSpan(
-                    trans_name, url_tran, domain, span_time, status_code, request_method, has_error)
+            start_time = getattr(Context.transaction_dict, 'start_time', None)
+            if start_time is None:
+                start_time = end_time
+                logger.debug('trace start_time not recorded')
             else:
-                trans_name = SwigSpan.createSpan(trans_name, domain, span_time)
-            logger.debug(
-                'create span: http: {http}, transaction_name: {xn}, duration: {duration}us.'.format(
-                    http=http_span, xn=trans_name, duration=span_time))
-        except Exception as e:
-            logger.error('appoptics_apm::end_trace create SPAN fail: {0}'.format(e))
+                start_time = int(start_time)
+            span_time = int(end_time - start_time)
+
+            try:
+                if http_span:
+                    request_method = getattr(Context.transaction_dict, 'request_method', None)
+                    status_code = getattr(Context.transaction_dict, 'status_code', None)
+                    if request_method is None or status_code is None:
+                        logger.debug(
+                            'http_span request info error request_method: {r}, status_code: {s}'.format(
+                                r=request_method, s=status_code))
+                    url_tran = None if trans_name else getattr(Context.transaction_dict, 'url_tran', None)
+                    if trans_name is None and url_tran is None:
+                        logger.debug(
+                            'http_span error: transaction_name is None, \
+                                    use set_transaction_name("transaction_name") to set')
+                    if status_code is None:
+                        status_code = 0
+                    has_error = bool(status_code > 499) and bool(status_code < 600)
+                    trans_name = SwigSpan.createHttpSpan(
+                        trans_name, url_tran, domain, span_time, status_code, request_method, has_error)
+                else:
+                    trans_name = SwigSpan.createSpan(trans_name, domain, span_time)
+                logger.debug(
+                    'create span: http: {http}, transaction_name: {xn}, duration: {duration}us.'.format(
+                        http=http_span, xn=trans_name, duration=span_time))
+            except Exception as e:
+                logger.error('appoptics_apm::end_trace create SPAN fail: {0}'.format(e))
 
         # True event is sampled, report it. Otherwise it's NullEvent or None, ignore it.
         if isinstance(event, Event):
             event.add_info('TransactionName', trans_name)
             if http_span:
-                event.add_info('Method', request_method)
+                event.add_info('Method', getattr(Context.transaction_dict, 'request_method', None))
                 event.add_info('HTTP-Host', getattr(Context.transaction_dict, 'domain', None))
                 event.add_info('URL', getattr(Context.transaction_dict, 'url_tran', None))
-                event.add_info('Status', status_code)
+                event.add_info('Status', getattr(Context.transaction_dict, 'status_code', 0))
             self.report(event)
         self._md = None
         Context.clear_default()
@@ -1023,7 +1056,7 @@ def _log_event(evt, keys=None, store_backtrace=True, backtrace=None, edge_str=No
     """Add the backtrace and edge, then send it out to the reporter.
     """
 
-    if isinstance(keys, dict) and 'Query' in keys and config['enable_sanitize_sql']:
+    if isinstance(keys, dict) and 'Query' in keys and appoptics_apm.config['enable_sanitize_sql']:
         keys['Query'] = _sanitize_sql(keys['Query'])
 
         if 'QueryArgs' in keys:
@@ -1073,7 +1106,8 @@ def start_trace(layer, xtr=None, keys=None, store_backtrace=True, backtrace=None
     return ctx
 
 
-def start_http_trace(layer, xtr=None, keys=None, store_backtrace=True, backtrace=None, transaction_name=None):
+def start_http_trace(
+        layer, xtr=None, keys=None, store_backtrace=True, backtrace=None, transaction_name=None, url_getter=None):
     """Start a new http trace, or continue one from an external layer.
 
     :layer: The layer name of the root of the trace.
@@ -1081,10 +1115,22 @@ def start_http_trace(layer, xtr=None, keys=None, store_backtrace=True, backtrace
     :keys: An optional dictionary of key-value pairs to report.
     :store_backtrace: Whether to report a backtrace. Default: True
     :backtrace: The backtrace to report. Default: this call.
+    :transaction_name: The name of the traced transaction. Default: None
+    :url_getter: UrlGetter instance to provide the request URL
     """
-    ctx = start_trace(layer, xtr, keys, store_backtrace, backtrace)
-    if ctx.is_valid() and transaction_name is not None:
-        ctx.set_transaction_name(transaction_name)
+    keys = keys or {}
+    forced_trace = 'Force' in keys
+
+    ctx, evt = Context.start_trace(layer, xtr=xtr, force=forced_trace, url_getter=url_getter)
+
+    if ctx.is_valid():  # Set it to the thread local storage even it's not sampled.
+        ctx.set_as_default()
+        if transaction_name is not None:
+            ctx.set_transaction_name(transaction_name)
+
+    if ctx.is_sampled():
+        _log_event(evt, keys=keys, store_backtrace=store_backtrace, backtrace=backtrace)
+
     return ctx
 
 
@@ -1105,13 +1151,10 @@ def end_trace(layer, keys=None, http=False):
 
     ctx = Context.get_default()
     evt = ctx.create_event('exit', layer)
-    if not ctx.is_sampled():
-        ctx.end_trace(evt)
-        return str(ctx)  # Always return the context id in string format.
-    else:
+    if ctx.is_sampled():
         evt = _update_event(evt, keys=keys, store_backtrace=False)
-        ctx_id = last_id()
-        ctx.end_trace(evt)
+    ctx_id = last_id()
+    ctx.end_trace(evt)
 
     return ctx_id
 
@@ -1270,7 +1313,7 @@ def last_id():
 def _function_signature(func):
     """Returns a string representation of the function signature of the given func."""
     name = func.__name__
-    (args, varargs, keywords, defaults) = inspect.getargspec(func)
+    (args, varargs, keywords, defaults) = inspect.getargspec(func)  # pylint: disable-msg=W1505
     argstrings = []
     if defaults:
         first = len(args) - len(defaults)
@@ -1607,25 +1650,25 @@ def _reporter():
 
     if not reporter_instance:
         reporter_instance = Reporter(
-            hostname_alias=config.get('hostname_alias'),
-            log_level=config.get('debug_level'),
-            log_file_path=config.get('logname'),
-            max_transactions=config.get('max_transactions'),
-            max_flush_wait_time=config.get('max_flush_wait_time'),
-            events_flush_interval=config.get('events_flush_interval'),
-            max_request_size_bytes=config.get('max_request_size_bytes'),
-            reporter=config.get('reporter'),
-            host=config.get('collector'),
-            service_key=config.get('service_key'),
-            trusted_path=config.get('trustedpath'),
-            buffer_size=config.get('bufsize'),
-            trace_metrics=config.get('trace_metrics'),
-            histogram_precision=config.get('histogram_precision'),
-            token_bucket_capacity=config.get('token_bucket_capacity'),
-            token_bucket_rate=config.get('token_bucket_rate'),
-            file_single=config.get('reporter_file_single'),
-            ec2_metadata_timeout=config.get('ec2_metadata_timeout'),
-            proxy=config.get('proxy'),
+            hostname_alias=appoptics_apm.config.get('hostname_alias'),
+            log_level=appoptics_apm.config.get('debug_level'),
+            log_file_path=appoptics_apm.config.get('logname'),
+            max_transactions=appoptics_apm.config.get('max_transactions'),
+            max_flush_wait_time=appoptics_apm.config.get('max_flush_wait_time'),
+            events_flush_interval=appoptics_apm.config.get('events_flush_interval'),
+            max_request_size_bytes=appoptics_apm.config.get('max_request_size_bytes'),
+            reporter=appoptics_apm.config.get('reporter'),
+            host=appoptics_apm.config.get('collector'),
+            service_key=appoptics_apm.config.get('service_key'),
+            trusted_path=appoptics_apm.config.get('trustedpath'),
+            buffer_size=appoptics_apm.config.get('bufsize'),
+            trace_metrics=appoptics_apm.config.get('trace_metrics'),
+            histogram_precision=appoptics_apm.config.get('histogram_precision'),
+            token_bucket_capacity=appoptics_apm.config.get('token_bucket_capacity'),
+            token_bucket_rate=appoptics_apm.config.get('token_bucket_rate'),
+            file_single=appoptics_apm.config.get('reporter_file_single'),
+            ec2_metadata_timeout=appoptics_apm.config.get('ec2_metadata_timeout'),
+            proxy=appoptics_apm.config.get('proxy'),
         )
 
     return reporter_instance
@@ -1660,27 +1703,35 @@ def _Event_addInfo_safe(func):
     return wrapped
 
 
-def sample_request(xtr):
+def sample_request(xtr, url_getter):
     """This functions calls the liboboe API to get the sampling decision. A side effect
     is to get the server-side sample_rate and sample_source.
     """
-    # TODO_Pylint: fix too long line
-    # pylint: disable=C0301
-    do_metrics, do_sample, sample_rate, sample_source, typ, auth, status_msg, auth_msg, status = SwigContext.getDecisions(
-        xtr)
-    # pylint: enable=C0301
+    args = (xtr, transaction_filter.url_filter.filter_url_and_get_tracing(url_getter)
+            ) if transaction_filter.url_filter and url_getter else (xtr, )
+    (
+        do_metrics,
+        do_sample,
+        sample_rate,
+        sample_source,
+        typ,
+        auth,
+        status_msg,
+        auth_msg,
+        status,
+    ) = SwigContext.getDecisions(*args)
 
     logger.debug(
         "sample result: do_sample={}, do_metrics={}, sample_rate={}, sample_source={}. "
         "type={}, auth={}, status={}, status_msg={}, auth_msg={}".format(
             do_sample, do_metrics, sample_rate, sample_source, typ, auth, status, status_msg, auth_msg))
 
+    setattr(Context.transaction_dict, 'do_metrics', do_metrics)
+
     if do_sample == 0:
         return False
-    # TODO: do_metrics is not processed.
     setattr(Context.transaction_dict, 'sample_rate', sample_rate)
     setattr(Context.transaction_dict, 'sample_source', sample_source)
-
     return True
 
 
@@ -1692,7 +1743,7 @@ setattr(SwigEvent, 'addInfo', _Event_addInfo_safe(getattr(SwigEvent, 'addInfo'))
 
 
 def _old_context_log(cls, layer, label, backtrace=False, **kwargs):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.log is deprecated. '
             'Please use appoptics_apm.log (and note signature change).')
@@ -1700,7 +1751,7 @@ def _old_context_log(cls, layer, label, backtrace=False, **kwargs):
 
 
 def _old_context_log_error(cls, exception=None, err_class=None, err_msg=None, backtrace=True):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.log_error is deprecated. '
             'Please use appoptics_apm.log_error (and note signature change).')
@@ -1719,7 +1770,7 @@ def _old_context_log_error(cls, exception=None, err_class=None, err_msg=None, ba
 
 
 def _old_context_log_exception(cls, msg=None, exc_info=None, backtrace=True):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.log_exception is deprecated. '
             'Please use appoptics_apm.log_exception (and note signature change).')
@@ -1736,7 +1787,7 @@ def _old_context_log_exception(cls, msg=None, exc_info=None, backtrace=True):
 
 
 def _old_context_trace(cls, layer='Python', xtr_hdr=None, kvs=None):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.trace is deprecated. '
             'Please use appoptics_apm.trace (and note signature change).')
@@ -1752,7 +1803,7 @@ def _old_context_profile_function(
         profile=False,
         callback=None,
         **entry_kvs):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.trace is deprecated. '
             'Please use appoptics_apm.trace (and note signature change).')
@@ -1768,7 +1819,7 @@ def _old_context_profile_function(
 
 def _old_context_log_method(
         cls, layer='Python', store_return=False, store_args=False, callback=None, profile=False, **entry_kvs):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.log_method is deprecated. '
             'Please use appoptics_apm.log_method (and note signature change).')
@@ -1783,7 +1834,7 @@ def _old_context_log_method(
 
 class _old_context_profile_block(profile_block):
     def __init__(self, *args, **kw):
-        if config['warn_deprecated']:
+        if appoptics_apm.config['warn_deprecated']:
             logger.debug(
                 'appoptics_apm.Context.profile_block is deprecated. '
                 'Please use appoptics_apm.profile_block (and note signature change).')
@@ -1791,7 +1842,7 @@ class _old_context_profile_block(profile_block):
 
 
 def _old_context_to_string(cls):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.toString is deprecated. '
             'Please use str(appoptics_apm.Context.get_default())')
@@ -1799,14 +1850,14 @@ def _old_context_to_string(cls):
 
 
 def _old_context_from_string(cls, md_string):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug('appoptics_apm.Context.fromString is deprecated.')
     c = Context(md_string)
     c.set_as_default()
 
 
 def _old_context_is_valid(cls):
-    if config['warn_deprecated']:
+    if appoptics_apm.config['warn_deprecated']:
         logger.debug(
             'appoptics_apm.Context.isValid is deprecated. '
             'Please use appoptics_apm.Context.get_default().is_valid()')
@@ -1923,9 +1974,3 @@ def appoptics_ready(wait_milliseconds=3000, integer_response=False):
         logger.warning(oboe_ready_code.code_values()[rc])
 
     return rc if integer_response else rc == oboe_ready_code.OBOE_SERVER_RESPONSE_OK[0]
-
-
-"""The AppOptics APM initializer will be executed when this package is imported by user application"""
-appoptics_apm_init()
-# Report an status event after everything is done.
-report_layer_init('Python')
